# #########################################################################
# Copyright (C) 2011 Marcelo Hashimoto
#
# This file is part of Polly.
#
# Polly is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Polly is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Polly. If not, see <http://www.gnu.org/licenses/>.
# #########################################################################



import os

from distutils.core import setup



NAME = u'polly'

ENCODING = u'UTF-8'



long_description = b'''
Polly is a Linux Twitter client designed for managing multiple columns of
multiple accounts, purposefully keeping them separated instead of merged.'''


packages = []

for dirpath, _, _ in os.walk(os.path.join(u'src', NAME)):
    dirname = dirpath

    names = []

    while dirname:
        dirname, basename = os.path.split(dirname)

        names.append(basename)

    package = u'.'.join(reversed(names[:-1]))

    packages.append(package.encode(ENCODING))


script = os.path.join(u'bin', NAME)

scripts = [script.encode(ENCODING)]


data_files = []

for dirpath, _, filenames in os.walk(u'share'):
    if filenames:
        directory = dirpath.encode(ENCODING)

        files = []

        for filename in filenames:
            file = os.path.join(dirpath, filename)

            files.append(file.encode(ENCODING))

        data_files.append((directory, files))

data_files.append(('/etc/gconf/schemas', ['polly.schemas']))


setup(name=b'Polly',
      version=b'0.93.11 (pre-alpha 3.11)',
      description=b'Linux Twitter client designed for multiple columns of multiple accounts',
      url=b'https://launchpad.net/polly',
      author=b'Marcelo Hashimoto',
      author_email=b'conscioususer@gmail.com',
      license=b'gpl3',
      long_description=long_description,
      platforms=[b'all'],
      packages=packages,
      package_dir={b'': b'src'},
      scripts=scripts,
      data_files=data_files)
